@@ -27,7 +27,7 @@
 
 #ifndef lint
 static const char rcsid[] _U_ =
-    "@(#) $Header: /tcpdump/master/libpcap/pcap-linux.c,v 1.107 2004/03/24 06:49:16 guy Exp $ (LBL)";
+    "@(#) $Header: /tcpdump/master/libpcap/pcap-linux.c,v 1.98.2.4 2003/11/21 10:20:46 guy Exp $ (LBL)";
 #endif
 
 /*
@@ -188,7 +188,6 @@ static int live_open_old(pcap_t *, const char *, int, int, char *);
 static int live_open_new(pcap_t *, const char *, int, int, char *);
 static int pcap_read_linux(pcap_t *, int, pcap_handler, u_char *);
 static int pcap_read_packet(pcap_t *, pcap_handler, u_char *);
-static int pcap_inject_linux(pcap_t *, const void *, size_t);
 static int pcap_stats_linux(pcap_t *, struct pcap_stat *);
 static int pcap_setfilter_linux(pcap_t *, struct bpf_program *);
 static void pcap_close_linux(pcap_t *);
@@ -405,7 +404,6 @@ pcap_open_live(const char *device, int snaplen, int promisc, int to_ms,
 	handle->selectable_fd = handle->fd;
 
 	handle->read_op = pcap_read_linux;
-	handle->inject_op = pcap_inject_linux;
 	handle->setfilter_op = pcap_setfilter_linux;
 	handle->set_datalink_op = NULL;	/* can't change data link type */
 	handle->getnonblock_op = pcap_getnonblock_fd;
@@ -674,65 +672,6 @@ pcap_read_packet(pcap_t *handle, pcap_handler callback, u_char *userdata)
 	return 1;
 }
 
-static int
-pcap_inject_linux(pcap_t *handle, const void *buf, size_t size)
-{
-#ifdef HAVE_PF_PACKET_SOCKETS
-	struct sockaddr_ll sa_ll;
-#endif
-	struct sockaddr_pkt sa_pkt;
-	int ret;
-
-#ifdef HAVE_PF_PACKET_SOCKETS
-	if (!handle->md.sock_packet) {
-		/* PF_PACKET socket */
-		if (handle->md.ifindex == -1) {
-			/*
-			 * Cooked mode - can't send.
-			 * XXX - how do you send on a bound cooked-mode
-			 * socket?
-			 */
-			strlcpy(handle->errbuf,
-			    "Sending packets isn't supported in cooked mode",
-			    PCAP_ERRBUF_SIZE);
-			return (-1);
-		}
-
-		memset(&sa_ll, 0, sizeof(sa_ll));
-		sa_ll.sll_family = AF_PACKET;
-		sa_ll.sll_ifindex = handle->md.ifindex;
-		/*
-		 * Do we have to set the hardware address?
-		 */
-		sa_ll.sll_protocol = htons(ETH_P_ALL);
-
-		ret = sendto(handle->fd, buf, size, 0, 
-			(struct sockaddr *)&sa_ll, sizeof(sa_ll));
-		if (ret == -1) {
-			snprintf(handle->errbuf, PCAP_ERRBUF_SIZE, "send: %s",
-			    pcap_strerror(errno));
-			return (-1);
-		}
-		return (ret);
-	}
-#endif
-	memset(&sa_pkt, 0, sizeof(sa_pkt));
-	sa_pkt.spkt_family = PF_INET;
-	strcpy(sa_pkt.spkt_device, handle->md.device);
-	/*
-	 * Do we have to set "spkt_protocol" to the Ethernet protocol?
-	 */
-
-	ret = sendto(handle->fd, buf, size, 0, (struct sockaddr *)&sa_pkt, 
-		sizeof(sa_pkt));
-	if (ret == -1) {
-		snprintf(handle->errbuf, PCAP_ERRBUF_SIZE, "send: %s",
-		    pcap_strerror(errno));
-		return (-1);
-	}
-	return (ret);
-}                           
-
 /*
  *  Get the statistics for the given packet capture handle.
  *  Reports the number of dropped packets iff the kernel supports
@@ -778,13 +717,9 @@ pcap_stats_linux(pcap_t *handle, struct pcap_stat *stats)
 		 * platforms, but the best approximation is to return
 		 * "tp_packets" as the count of packets and "tp_drops"
 		 * as the count of drops.
-		 *
-		 * Keep a running total because each call to 
-		 *    getsockopt(handle->fd, SOL_PACKET, PACKET_STATISTICS, ....
-		 * resets the counters to zero.
 		 */
-		handle->md.stat.ps_recv += kstats.tp_packets;
-		handle->md.stat.ps_drop += kstats.tp_drops;
+		handle->md.stat.ps_recv = kstats.tp_packets;
+		handle->md.stat.ps_drop = kstats.tp_drops;
 	}
 	else
 	{
@@ -1013,34 +948,6 @@ static void map_arphrd_to_dlt(pcap_t *handle, int arptype, int cooked_ok)
 	switch (arptype) {
 
 	case ARPHRD_ETHER:
-		/*
-		 * This is (presumably) a real Ethernet capture; give it a
-		 * link-layer-type list with DLT_EN10MB and DLT_DOCSIS, so
-		 * that an application can let you choose it, in case you're
-		 * capturing DOCSIS traffic that a Cisco Cable Modem
-		 * Termination System is putting out onto an Ethernet (it
-		 * doesn't put an Ethernet header onto the wire, it puts raw
-		 * DOCSIS frames out on the wire inside the low-level
-		 * Ethernet framing).
-		 *
-		 * XXX - are there any sorts of "fake Ethernet" that have
-		 * ARPHRD_ETHER but that *shouldn't offer DLT_DOCSIS as
-		 * a Cisco CMTS won't put traffic onto it or get traffic
-		 * bridged onto it?  ISDN is handled in "live_open_new()",
-		 * as we fall back on cooked mode there; are there any
-		 * others?
-		 */
-		handle->dlt_list = (u_int *) malloc(sizeof(u_int) * 2);
-		/*
-		 * If that fails, just leave the list empty.
-		 */
-		if (handle->dlt_list != NULL) {
-			handle->dlt_list[0] = DLT_EN10MB;
-			handle->dlt_list[1] = DLT_DOCSIS;
-			handle->dlt_count = 2;
-		}
-		/* FALLTHROUGH */
-
 	case ARPHRD_METRICOM:
 	case ARPHRD_LOOPBACK:
 		handle->linktype = DLT_EN10MB;
@@ -1282,7 +1189,7 @@ live_open_new(pcap_t *handle, const char *device, int promisc,
 	      int to_ms, char *ebuf)
 {
 #ifdef HAVE_PF_PACKET_SOCKETS
-	int			sock_fd = -1, arptype;
+	int			sock_fd = -1, device_id, arptype;
 	int			err;
 	int			fatal_err = 0;
 	struct packet_mreq	mr;
@@ -1371,17 +1278,6 @@ live_open_new(pcap_t *handle, const char *device, int promisc,
 				}
 				handle->md.cooked = 1;
 
-				/*
-				 * Get rid of any link-layer type list
-				 * we allocated - this only supports cooked
-				 * capture.
-				 */
-				if (handle->dlt_list != NULL) {
-					free(handle->dlt_list);
-					handle->dlt_list = NULL;
-					handle->dlt_count = 0;
-				}
-
 				if (handle->linktype == -1) {
 					/*
 					 * Warn that we're falling back on
@@ -1398,16 +1294,15 @@ live_open_new(pcap_t *handle, const char *device, int promisc,
 				}
 				/* IrDA capture is not a real "cooked" capture,
 				 * it's IrLAP frames, not IP packets. */
-				if (handle->linktype != DLT_LINUX_IRDA)
+				if(handle->linktype != DLT_LINUX_IRDA)
 					handle->linktype = DLT_LINUX_SLL;
 			}
 
-			handle->md.ifindex = iface_get_id(sock_fd, device, ebuf);
-			if (handle->md.ifindex == -1)
+			device_id = iface_get_id(sock_fd, device, ebuf);
+			if (device_id == -1)
 				break;
 
-			if ((err = iface_bind(sock_fd, handle->md.ifindex,
-			    ebuf)) < 0) {
+			if ((err = iface_bind(sock_fd, device_id, ebuf)) < 0) {
 				if (err == -2)
 					fatal_err = 1;
 				break;
@@ -1420,15 +1315,14 @@ live_open_new(pcap_t *handle, const char *device, int promisc,
 			handle->linktype = DLT_LINUX_SLL;
 
 			/*
-			 * We're not bound to a device.
-			 * XXX - true?  Or true only if we're using
-			 * the "any" device?
-			 * For now, we're using this as an indication
-			 * that we can't transmit; stop doing that only
-			 * if we figure out how to transmit in cooked
-			 * mode.
+			 * XXX - squelch GCC complaints about
+			 * uninitialized variables; if we can't
+			 * select promiscuous mode on all interfaces,
+			 * we should move the code below into the
+			 * "if (device)" branch of the "if" and
+			 * get rid of the next statement.
 			 */
-			handle->md.ifindex = -1;
+			device_id = -1;
 		}
 
 		/*
@@ -1452,7 +1346,7 @@ live_open_new(pcap_t *handle, const char *device, int promisc,
 
 		if (device && promisc) {
 			memset(&mr, 0, sizeof(mr));
-			mr.mr_ifindex = handle->md.ifindex;
+			mr.mr_ifindex = device_id;
 			mr.mr_type    = PACKET_MR_PROMISC;
 			if (setsockopt(sock_fd, SOL_PACKET,
 				PACKET_ADD_MEMBERSHIP, &mr, sizeof(mr)) == -1)
@@ -1474,14 +1368,9 @@ live_open_new(pcap_t *handle, const char *device, int promisc,
 	if (sock_fd != -1)
 		close(sock_fd);
 
-	if (fatal_err) {
-		/*
-		 * Get rid of any link-layer type list we allocated.
-		 */
-		if (handle->dlt_list != NULL)
-			free(handle->dlt_list);
+	if (fatal_err)
 		return -2;
-	} else
+	else
 		return 0;
 #else
 	strncpy(ebuf,
