@@ -30,7 +30,7 @@
 
 #ifndef lint
 static const char rcsid[] _U_ =
-    "@(#) $Header: /tcpdump/master/libpcap/savefile.c,v 1.106 2004/03/23 19:18:08 guy Exp $ (LBL)";
+    "@(#) $Header: /tcpdump/master/libpcap/savefile.c,v 1.92.2.11 2004/03/11 23:46:14 guy Exp $ (LBL)";
 #endif
 
 #ifdef HAVE_CONFIG_H
@@ -156,6 +156,11 @@ static const char rcsid[] _U_ =
 
 #define LINKTYPE_PPP_ETHER	51		/* NetBSD PPP-over-Ethernet */
 
+/*
+ * This isn't supported in libpcap 0.8[.x], but is supported in the
+ * current CVS version; we include it here to note that it's not available
+ * for anybody else to use.
+ */
 #define LINKTYPE_SYMANTEC_FIREWALL 99		/* Symantec Enterprise Firewall */
 
 #define LINKTYPE_ATM_RFC1483	100		/* LLC/SNAP-encapsulated ATM */
@@ -242,6 +247,11 @@ static const char rcsid[] _U_ =
 #define LINKTYPE_RAWSS7_MTP3    141             /* definitions */
 #define LINKTYPE_RAWSS7_SCCP    142
 
+/*
+ * This isn't supported in libpcap 0.8[.x], but is supported in the
+ * current CVS version; we include it here to note that it's not available
+ * for anybody else to use.
+ */
 #define LINKTYPE_DOCSIS		143		/* DOCSIS MAC frames */
 
 #define LINKTYPE_LINUX_IRDA	144		/* Linux-IrDA */
@@ -574,14 +584,6 @@ sf_stats(pcap_t *p, struct pcap_stat *ps)
 	return (-1);
 }
 
-static int
-sf_inject(pcap_t *p, const void *buf _U_, size_t size _U_)
-{
-	strlcpy(p->errbuf, "Sending packets isn't supported on savefiles",
-	    PCAP_ERRBUF_SIZE);
-	return (-1);
-}
-
 static void
 sf_close(pcap_t *p)
 {
@@ -738,7 +740,6 @@ pcap_open_offline(const char *fname, char *errbuf)
 #endif
 
 	p->read_op = pcap_offline_read;
-	p->inject_op = sf_inject;
 	p->setfilter_op = install_bpf_program;
 	p->set_datalink_op = NULL;	/* we don't support munging link-layer headers */
 	p->getnonblock_op = sf_getnonblock;
@@ -993,15 +994,13 @@ pcap_dump_open(pcap_t *p, const char *fname)
 		f = fopen(fname, "w");
 #else
 		f = fopen(fname, "wb");
+		setbuf(f, NULL);	/* XXX - why? */
 #endif
 		if (f == NULL) {
 			snprintf(p->errbuf, PCAP_ERRBUF_SIZE, "%s: %s",
 			    fname, pcap_strerror(errno));
 			return (NULL);
 		}
-#ifdef WIN32
-		setbuf(f, NULL);	/* XXX - why? */
-#endif
 	}
 	(void)sf_write_header(f, linktype, p->tzoff, p->snapshot);
 	return ((pcap_dumper_t *)f);
